[![Build Status](https://travis-ci.org/grburgess/gbmgeometry.svg?branch=master)](https://travis-ci.org/grburgess/gbmgeometry)
[![codecov](https://codecov.io/gh/grburgess/gbmgeometry/branch/master/graph/badge.svg)](https://codecov.io/gh/grburgess/gbmgeometry)
# gbmgeometry
Routines to handle GBM geometry and plotting 

## Requirements
* astropy
* numpy
* matplotlib
* scipy
* Basemap
* seaborn
* spherical_geometry

## Install

$> python setup.py install
